@@ -55,6 +55,27 @@ from packaging.specifiers import SpecifierSet
 logger = logging.getLogger(__name__)
 
 
+def _slice(data, skipped):
+    """Slice data if it is an array with more than one element.
+
+    * If ``data`` is a scalar, return the scalar.
+    * If ``data`` is is one-element array, extract and return it.
+    * If ``data`` is any other array, slice it according to `skipped` and return it.
+
+    Args:
+        data (scalar or array-like): input array
+        skipped (bool): number of samples to skip the beginning
+
+    Returns:
+        (scalar or array-like) Sliced data
+    """
+    if numpy.isscalar(data):
+        return data
+    if data.size == 1:
+        return data[0]
+    return data[skipped:]
+
+
 class Data():
     """Interface object that helps loading data and using them to evaluate combinations.
 
@@ -213,9 +234,11 @@ class Data():
                 logger.debug("Using orbit file version %s", version)
                 if version.is_devrelease:
                     logger.warning("You are using an orbit file in a development version")
-                if version in SpecifierSet('~= 1.0', True):
+                if version in SpecifierSet('== 1.*', True):
                     attr = 't0' if dataset == 'tcb/ltt' else 'tau0'
                     t0 = float(orbitf.attrs[attr])
+                elif version in SpecifierSet('== 2.*', True):
+                    t0 = float(orbitf.attrs['t0'])
                 else:
                     raise ValueError(f"unsupported lisaorbits version '{version}'")
         logger.debug("Using interpolating time vector (fs=%s, size=%s, t0=%s)", fs, size, t0)
@@ -227,13 +250,16 @@ class Data():
             # Check orbit file version
             version = Version(orbitf.attrs['version'])
             logger.debug("Using orbit file version %s", version)
-            if version.is_devrelease:
-                logger.warning("You are using an orbit file in a development version")
-            if version in SpecifierSet('~= 1.0', True):
+            if version in SpecifierSet('== 1.*', True):
                 times = orbitf['tcb']['t'][:] if dataset == 'tcb/ltt' else orbitf['tps']['tau'][:]
                 for mosa in cls.MOSAS:
                     values = orbitf[f'tcb/l_{mosa}']['tt'] if dataset == 'tcb/ltt' else orbitf[f'tps/l_{mosa}']['ppr']
                     delays[f'd_{mosa}'] = InterpolatedUnivariateSpline(times, values, k=5, ext='raise')(t)
+            elif version in SpecifierSet('== 2.*', True):
+                times = orbitf.attrs['t0'] + numpy.arange(orbitf.attrs['size']) * orbitf.attrs['dt']
+                values = orbitf[dataset]
+                for i, mosa in enumerate(cls.MOSAS):
+                    delays[f'd_{mosa}'] = InterpolatedUnivariateSpline(times, values[:, i], k=5, ext='raise')(t)
             else:
                 raise ValueError(f"unsupported lisaorbits version '{version}'")
         # Create measurements dictionary
@@ -293,7 +319,7 @@ class Data():
                     key_offsets = cls.LISANODE_OFFSETS[key]
                     # Correct for beatnote polarity and convert to Hz
                     measurements[key] = central_freq * hdf5[key_fluctuations][skipped:, 1] \
-                            * numpy.sign(hdf5[key_offsets][skipped:, 1])
+                        * numpy.sign(hdf5[key_offsets][skipped:, 1])
             elif signals == 'offsets':
                 for key, key_offsets in cls.LISANODE_OFFSETS.items():
                     # Convert from MHz to Hz
@@ -381,49 +407,49 @@ class Data():
             for mosa in cls.MOSAS:
                 # Load measurements
                 if signals == 'fluctuations':
-                    measurements[f'isi_{mosa}'] = Data._slice(instrument.isc_carrier_fluctuations[mosa], skipped)
-                    measurements[f'rfi_{mosa}'] = Data._slice(instrument.ref_carrier_fluctuations[mosa], skipped)
-                    measurements[f'tmi_{mosa}'] = Data._slice(instrument.tm_carrier_fluctuations[mosa], skipped)
-                    measurements[f'isi_sb_{mosa}'] = Data._slice(instrument.isc_usb_fluctuations[mosa], skipped)
-                    measurements[f'rfi_sb_{mosa}'] = Data._slice(instrument.ref_usb_fluctuations[mosa], skipped)
+                    measurements[f'isi_{mosa}'] = _slice(instrument.isc_carrier_fluctuations[mosa], skipped)
+                    measurements[f'rfi_{mosa}'] = _slice(instrument.ref_carrier_fluctuations[mosa], skipped)
+                    measurements[f'tmi_{mosa}'] = _slice(instrument.tm_carrier_fluctuations[mosa], skipped)
+                    measurements[f'isi_sb_{mosa}'] = _slice(instrument.isc_usb_fluctuations[mosa], skipped)
+                    measurements[f'rfi_sb_{mosa}'] = _slice(instrument.ref_usb_fluctuations[mosa], skipped)
                 elif signals == 'offsets':
-                    measurements[f'isi_{mosa}'] = Data._slice(instrument.isc_carrier_offsets[mosa], skipped)
-                    measurements[f'rfi_{mosa}'] = Data._slice(instrument.ref_carrier_offsets[mosa], skipped)
-                    measurements[f'tmi_{mosa}'] = Data._slice(instrument.tm_carrier_offsets[mosa], skipped)
-                    measurements[f'isi_sb_{mosa}'] = Data._slice(instrument.isc_usb_offsets[mosa], skipped)
-                    measurements[f'rfi_sb_{mosa}'] = Data._slice(instrument.ref_usb_offsets[mosa], skipped)
+                    measurements[f'isi_{mosa}'] = _slice(instrument.isc_carrier_offsets[mosa], skipped)
+                    measurements[f'rfi_{mosa}'] = _slice(instrument.ref_carrier_offsets[mosa], skipped)
+                    measurements[f'tmi_{mosa}'] = _slice(instrument.tm_carrier_offsets[mosa], skipped)
+                    measurements[f'isi_sb_{mosa}'] = _slice(instrument.isc_usb_offsets[mosa], skipped)
+                    measurements[f'rfi_sb_{mosa}'] = _slice(instrument.ref_usb_offsets[mosa], skipped)
                 elif signals == 'total':
-                    measurements[f'isi_{mosa}'] = Data._slice(instrument.isc_carriers[mosa], skipped)
-                    measurements[f'rfi_{mosa}'] = Data._slice(instrument.ref_carriers[mosa], skipped)
-                    measurements[f'tmi_{mosa}'] = Data._slice(instrument.tm_carriers[mosa], skipped)
-                    measurements[f'isi_sb_{mosa}'] = Data._slice(instrument.isc_usbs[mosa], skipped)
-                    measurements[f'rfi_sb_{mosa}'] = Data._slice(instrument.ref_usbs[mosa], skipped)
+                    measurements[f'isi_{mosa}'] = _slice(instrument.isc_carriers[mosa], skipped)
+                    measurements[f'rfi_{mosa}'] = _slice(instrument.ref_carriers[mosa], skipped)
+                    measurements[f'tmi_{mosa}'] = _slice(instrument.tm_carriers[mosa], skipped)
+                    measurements[f'isi_sb_{mosa}'] = _slice(instrument.isc_usbs[mosa], skipped)
+                    measurements[f'rfi_sb_{mosa}'] = _slice(instrument.ref_usbs[mosa], skipped)
                 # Load MPRs
-                delays[f'd_{mosa}'] = Data._slice(instrument.mprs[mosa], skipped)
+                delays[f'd_{mosa}'] = _slice(instrument.mprs[mosa], skipped)
         elif version in SpecifierSet('< 1.2', True):
             fs = instrument.fs
             for mosa in cls.MOSAS:
                 # Load measurements
                 if signals == 'fluctuations':
-                    measurements[f'isi_{mosa}'] = Data._slice(instrument.isi_carrier_fluctuations[mosa], skipped)
-                    measurements[f'rfi_{mosa}'] = Data._slice(instrument.rfi_carrier_fluctuations[mosa], skipped)
-                    measurements[f'tmi_{mosa}'] = Data._slice(instrument.tmi_carrier_fluctuations[mosa], skipped)
-                    measurements[f'isi_sb_{mosa}'] = Data._slice(instrument.isi_usb_fluctuations[mosa], skipped)
-                    measurements[f'rfi_sb_{mosa}'] = Data._slice(instrument.rfi_usb_fluctuations[mosa], skipped)
+                    measurements[f'isi_{mosa}'] = _slice(instrument.isi_carrier_fluctuations[mosa], skipped)
+                    measurements[f'rfi_{mosa}'] = _slice(instrument.rfi_carrier_fluctuations[mosa], skipped)
+                    measurements[f'tmi_{mosa}'] = _slice(instrument.tmi_carrier_fluctuations[mosa], skipped)
+                    measurements[f'isi_sb_{mosa}'] = _slice(instrument.isi_usb_fluctuations[mosa], skipped)
+                    measurements[f'rfi_sb_{mosa}'] = _slice(instrument.rfi_usb_fluctuations[mosa], skipped)
                 elif signals == 'offsets':
-                    measurements[f'isi_{mosa}'] = Data._slice(instrument.isi_carrier_offsets[mosa], skipped)
-                    measurements[f'rfi_{mosa}'] = Data._slice(instrument.rfi_carrier_offsets[mosa], skipped)
-                    measurements[f'tmi_{mosa}'] = Data._slice(instrument.tmi_carrier_offsets[mosa], skipped)
-                    measurements[f'isi_sb_{mosa}'] = Data._slice(instrument.isi_usb_offsets[mosa], skipped)
-                    measurements[f'rfi_sb_{mosa}'] = Data._slice(instrument.rfi_usb_offsets[mosa], skipped)
+                    measurements[f'isi_{mosa}'] = _slice(instrument.isi_carrier_offsets[mosa], skipped)
+                    measurements[f'rfi_{mosa}'] = _slice(instrument.rfi_carrier_offsets[mosa], skipped)
+                    measurements[f'tmi_{mosa}'] = _slice(instrument.tmi_carrier_offsets[mosa], skipped)
+                    measurements[f'isi_sb_{mosa}'] = _slice(instrument.isi_usb_offsets[mosa], skipped)
+                    measurements[f'rfi_sb_{mosa}'] = _slice(instrument.rfi_usb_offsets[mosa], skipped)
                 elif signals == 'total':
-                    measurements[f'isi_{mosa}'] = Data._slice(instrument.isi_carriers[mosa], skipped)
-                    measurements[f'rfi_{mosa}'] = Data._slice(instrument.rfi_carriers[mosa], skipped)
-                    measurements[f'tmi_{mosa}'] = Data._slice(instrument.tmi_carriers[mosa], skipped)
-                    measurements[f'isi_sb_{mosa}'] = Data._slice(instrument.isi_usbs[mosa], skipped)
-                    measurements[f'rfi_sb_{mosa}'] = Data._slice(instrument.rfi_usbs[mosa], skipped)
+                    measurements[f'isi_{mosa}'] = _slice(instrument.isi_carriers[mosa], skipped)
+                    measurements[f'rfi_{mosa}'] = _slice(instrument.rfi_carriers[mosa], skipped)
+                    measurements[f'tmi_{mosa}'] = _slice(instrument.tmi_carriers[mosa], skipped)
+                    measurements[f'isi_sb_{mosa}'] = _slice(instrument.isi_usbs[mosa], skipped)
+                    measurements[f'rfi_sb_{mosa}'] = _slice(instrument.rfi_usbs[mosa], skipped)
                 # Load MPRs
-                delays[f'd_{mosa}'] = Data._slice(instrument.mprs[mosa], skipped)
+                delays[f'd_{mosa}'] = _slice(instrument.mprs[mosa], skipped)
         else:
             raise ValueError(f"unsupported lisainstrument version '{version}'")
         # Create instance
@@ -458,49 +484,49 @@ class Data():
                 for mosa in cls.MOSAS:
                     # Load measurements
                     if signals == 'fluctuations':
-                        measurements[f'isi_{mosa}'] = Data._slice(hdf5['isc_carrier_fluctuations'][mosa], skipped)
-                        measurements[f'rfi_{mosa}'] = Data._slice(hdf5['ref_carrier_fluctuations'][mosa], skipped)
-                        measurements[f'tmi_{mosa}'] = Data._slice(hdf5['tm_carrier_fluctuations'][mosa], skipped)
-                        measurements[f'isi_sb_{mosa}'] = Data._slice(hdf5['isc_usb_fluctuations'][mosa], skipped)
-                        measurements[f'rfi_sb_{mosa}'] = Data._slice(hdf5['ref_usb_fluctuations'][mosa], skipped)
+                        measurements[f'isi_{mosa}'] = _slice(hdf5['isc_carrier_fluctuations'][mosa], skipped)
+                        measurements[f'rfi_{mosa}'] = _slice(hdf5['ref_carrier_fluctuations'][mosa], skipped)
+                        measurements[f'tmi_{mosa}'] = _slice(hdf5['tm_carrier_fluctuations'][mosa], skipped)
+                        measurements[f'isi_sb_{mosa}'] = _slice(hdf5['isc_usb_fluctuations'][mosa], skipped)
+                        measurements[f'rfi_sb_{mosa}'] = _slice(hdf5['ref_usb_fluctuations'][mosa], skipped)
                     elif signals == 'offsets':
-                        measurements[f'isi_{mosa}'] = Data._slice(hdf5['isc_carrier_offsets'][mosa], skipped)
-                        measurements[f'rfi_{mosa}'] = Data._slice(hdf5['ref_carrier_offsets'][mosa], skipped)
-                        measurements[f'tmi_{mosa}'] = Data._slice(hdf5['tm_carrier_offsets'][mosa], skipped)
-                        measurements[f'isi_sb_{mosa}'] = Data._slice(hdf5['isc_usb_offsets'][mosa], skipped)
-                        measurements[f'rfi_sb_{mosa}'] = Data._slice(hdf5['ref_usb_offsets'][mosa], skipped)
+                        measurements[f'isi_{mosa}'] = _slice(hdf5['isc_carrier_offsets'][mosa], skipped)
+                        measurements[f'rfi_{mosa}'] = _slice(hdf5['ref_carrier_offsets'][mosa], skipped)
+                        measurements[f'tmi_{mosa}'] = _slice(hdf5['tm_carrier_offsets'][mosa], skipped)
+                        measurements[f'isi_sb_{mosa}'] = _slice(hdf5['isc_usb_offsets'][mosa], skipped)
+                        measurements[f'rfi_sb_{mosa}'] = _slice(hdf5['ref_usb_offsets'][mosa], skipped)
                     elif signals == 'total':
-                        measurements[f'isi_{mosa}'] = Data._slice(hdf5['isc_carriers'][mosa], skipped)
-                        measurements[f'rfi_{mosa}'] = Data._slice(hdf5['ref_carriers'][mosa], skipped)
-                        measurements[f'tmi_{mosa}'] = Data._slice(hdf5['tm_carriers'][mosa], skipped)
-                        measurements[f'isi_sb_{mosa}'] = Data._slice(hdf5['isc_usbs'][mosa], skipped)
-                        measurements[f'rfi_sb_{mosa}'] = Data._slice(hdf5['ref_usbs'][mosa], skipped)
+                        measurements[f'isi_{mosa}'] = _slice(hdf5['isc_carriers'][mosa], skipped)
+                        measurements[f'rfi_{mosa}'] = _slice(hdf5['ref_carriers'][mosa], skipped)
+                        measurements[f'tmi_{mosa}'] = _slice(hdf5['tm_carriers'][mosa], skipped)
+                        measurements[f'isi_sb_{mosa}'] = _slice(hdf5['isc_usbs'][mosa], skipped)
+                        measurements[f'rfi_sb_{mosa}'] = _slice(hdf5['ref_usbs'][mosa], skipped)
                     # Load MPRs
-                    delays[f'd_{mosa}'] = Data._slice(hdf5['mprs'][mosa], skipped)
+                    delays[f'd_{mosa}'] = _slice(hdf5['mprs'][mosa], skipped)
             elif version in SpecifierSet('< 1.2', True):
                 fs = hdf5.attrs['fs']
                 for mosa in cls.MOSAS:
                     # Load measurements
                     if signals == 'fluctuations':
-                        measurements[f'isi_{mosa}'] = Data._slice(hdf5['isi_carrier_fluctuations'][mosa], skipped)
-                        measurements[f'rfi_{mosa}'] = Data._slice(hdf5['rfi_carrier_fluctuations'][mosa], skipped)
-                        measurements[f'tmi_{mosa}'] = Data._slice(hdf5['tmi_carrier_fluctuations'][mosa], skipped)
-                        measurements[f'isi_sb_{mosa}'] = Data._slice(hdf5['isi_usb_fluctuations'][mosa], skipped)
-                        measurements[f'rfi_sb_{mosa}'] = Data._slice(hdf5['rfi_usb_fluctuations'][mosa], skipped)
+                        measurements[f'isi_{mosa}'] = _slice(hdf5['isi_carrier_fluctuations'][mosa], skipped)
+                        measurements[f'rfi_{mosa}'] = _slice(hdf5['rfi_carrier_fluctuations'][mosa], skipped)
+                        measurements[f'tmi_{mosa}'] = _slice(hdf5['tmi_carrier_fluctuations'][mosa], skipped)
+                        measurements[f'isi_sb_{mosa}'] = _slice(hdf5['isi_usb_fluctuations'][mosa], skipped)
+                        measurements[f'rfi_sb_{mosa}'] = _slice(hdf5['rfi_usb_fluctuations'][mosa], skipped)
                     elif signals == 'offsets':
-                        measurements[f'isi_{mosa}'] = Data._slice(hdf5['isi_carrier_offsets'][mosa], skipped)
-                        measurements[f'rfi_{mosa}'] = Data._slice(hdf5['rfi_carrier_offsets'][mosa], skipped)
-                        measurements[f'tmi_{mosa}'] = Data._slice(hdf5['tmi_carrier_offsets'][mosa], skipped)
-                        measurements[f'isi_sb_{mosa}'] = Data._slice(hdf5['isi_usb_offsets'][mosa], skipped)
-                        measurements[f'rfi_sb_{mosa}'] = Data._slice(hdf5['rfi_usb_offsets'][mosa], skipped)
+                        measurements[f'isi_{mosa}'] = _slice(hdf5['isi_carrier_offsets'][mosa], skipped)
+                        measurements[f'rfi_{mosa}'] = _slice(hdf5['rfi_carrier_offsets'][mosa], skipped)
+                        measurements[f'tmi_{mosa}'] = _slice(hdf5['tmi_carrier_offsets'][mosa], skipped)
+                        measurements[f'isi_sb_{mosa}'] = _slice(hdf5['isi_usb_offsets'][mosa], skipped)
+                        measurements[f'rfi_sb_{mosa}'] = _slice(hdf5['rfi_usb_offsets'][mosa], skipped)
                     elif signals == 'total':
-                        measurements[f'isi_{mosa}'] = Data._slice(hdf5['isi_carriers'][mosa], skipped)
-                        measurements[f'rfi_{mosa}'] = Data._slice(hdf5['rfi_carriers'][mosa], skipped)
-                        measurements[f'tmi_{mosa}'] = Data._slice(hdf5['tmi_carriers'][mosa], skipped)
-                        measurements[f'isi_sb_{mosa}'] = Data._slice(hdf5['isi_usbs'][mosa], skipped)
-                        measurements[f'rfi_sb_{mosa}'] = Data._slice(hdf5['rfi_usbs'][mosa], skipped)
+                        measurements[f'isi_{mosa}'] = _slice(hdf5['isi_carriers'][mosa], skipped)
+                        measurements[f'rfi_{mosa}'] = _slice(hdf5['rfi_carriers'][mosa], skipped)
+                        measurements[f'tmi_{mosa}'] = _slice(hdf5['tmi_carriers'][mosa], skipped)
+                        measurements[f'isi_sb_{mosa}'] = _slice(hdf5['isi_usbs'][mosa], skipped)
+                        measurements[f'rfi_sb_{mosa}'] = _slice(hdf5['rfi_usbs'][mosa], skipped)
                     # Load MPRs
-                    delays[f'd_{mosa}'] = Data._slice(hdf5['mprs'][mosa], skipped)
+                    delays[f'd_{mosa}'] = _slice(hdf5['mprs'][mosa], skipped)
             else:
                 raise ValueError(f"unsupported measurement file version '{version}'")
         # Create instance
@@ -509,7 +535,7 @@ class Data():
         return data
 
     @classmethod
-    def from_gws(cls, path, orbits, skipped=0, orbit_dataset='tps/ppr'):
+    def from_gws(cls, path, orbits, skipped=0, gw_dataset='tps', orbit_dataset='tps/ppr'):
         """Load data from `LISA GW Response <https://gitlab.in2p3.fr/lisa-simulation/gw-response>`_.
 
         **Delays** are read from an orbit file, c.f. :meth:`pytdi.Data.from_orbits`.
@@ -532,46 +558,57 @@ class Data():
             path (str): path to gravitational-wave file
             orbits (str): path to orbit file
             skipped (bool): number of samples to skip the beginning
+            gw_dataset (str): GW dataset to use, either ``'tps'`` or ``'tcb'``
             orbit_dataset (str): orbit dataset to use, either ``'tps/ppr'`` or ``'tcb/ltt'``
         """
-        logger.info("Loading gravitational-wave file '%s'", path)
+        # Warn if inconsistent GW and orbit datasets
+        if (gw_dataset == 'tps' and orbit_dataset != 'tps/ppr') \
+            or (gw_dataset == 'tcb' and orbit_dataset != 'tcb/ltt'):
+            logger.warning("Using inconsistent orbits and GW file datasets ('%s' and '%s')",
+                orbit_dataset, gw_dataset)
+
         # Load measurements
-        with h5py.File(path, 'r') as gws:
-            # Check version and load data
-            version = Version(gws.attrs['version'])
+        logger.info("Loading gravitational-wave file '%s'", path)
+        with h5py.File(path, 'r') as gwf:
+            version = Version(gwf.attrs['version'])
             logger.debug("Using GW file version %s", version)
             if version.is_devrelease:
                 logger.warning("You are using a GW file in a development version")
-            if version in SpecifierSet('~= 0.1', True) or version in SpecifierSet('~= 1.0', True):
-                fs = gws.attrs['fs']
-                t0 = gws.attrs['t0']
-
+            if version in SpecifierSet('< 1.1', True):
                 measurements = {}
                 for mosa in cls.MOSAS:
-                    measurements[f'isi_{mosa}'] = -Data._slice(gws[f'l_{mosa}'], skipped)
-                    measurements[f'isi_sb_{mosa}'] = -Data._slice(gws[f'l_{mosa}'], skipped)
-                    measurements[f'tmi_{mosa}'] = 0
-                    measurements[f'rfi_{mosa}'] = 0
-                    measurements[f'rfi_sb_{mosa}'] = 0
+                    measurements[f'isi_{mosa}'] = -_slice(gwf[f'l_{mosa}'], skipped)
+                    measurements[f'isi_sb_{mosa}'] = -_slice(gwf[f'l_{mosa}'], skipped)
+                    measurements[f'tmi_{mosa}'] = 0.0
+                    measurements[f'rfi_{mosa}'] = 0.0
+                    measurements[f'rfi_sb_{mosa}'] = 0.0
+                fs = gwf.attrs['fs']
+                t0 = gwf.attrs['t0']
+            elif version in SpecifierSet('== 1.1', True):
+                if gw_dataset not in gwf:
+                    raise KeyError(f"cannot find dataset '{gw_dataset}' in '{path}'")
+                measurements = {}
+                for mosa in cls.MOSAS:
+                    measurements[f'isi_{mosa}'] = -_slice(gwf[f'{gw_dataset}/l_{mosa}'], skipped)
+                    measurements[f'isi_sb_{mosa}'] = -_slice(gwf[f'{gw_dataset}/l_{mosa}'], skipped)
+                    measurements[f'tmi_{mosa}'] = 0.0
+                    measurements[f'rfi_{mosa}'] = 0.0
+                    measurements[f'rfi_sb_{mosa}'] = 0.0
+                fs = gwf.attrs['fs']
+                t0 = gwf.attrs['t0']
+            elif version in SpecifierSet('== 2.*', True):
+                if gw_dataset not in gwf:
+                    raise KeyError(f"cannot find dataset '{gw_dataset}' in '{path}'")
+                measurements = {}
+                for imosa, mosa in enumerate(cls.MOSAS):
+                    measurements[f'isi_{mosa}'] = -_slice(gwf[f'{gw_dataset}/y'][:, imosa], skipped)
+                    measurements[f'isi_sb_{mosa}'] = -_slice(gwf[f'{gw_dataset}/y'][:, imosa], skipped)
+                    measurements[f'tmi_{mosa}'] = 0.0
+                    measurements[f'rfi_{mosa}'] = 0.0
+                    measurements[f'rfi_sb_{mosa}'] = 0.0
+                fs = gwf.attrs['fs']
+                t0 = gwf.attrs['t0']
             else:
-                raise ValueError(f"unsupported lisagwresponse version '{version}'")
+                raise ValueError(f"unsupported GW file version '{version}'")
         # Load delays from orbit file
         return cls.from_orbits(orbits, fs, t0, orbit_dataset, **measurements)
-
-    @staticmethod
-    def _slice(data, skipped):
-        """Slice data if it is an array with more than one element.
-
-        * If ``data`` is a scalar, return the scalar.
-        * If ``data`` is is one-element array, extract and return it.
-        * If ``data`` is any other array, slice it according to `skipped` and return it.
-
-        Args:
-            data (array-like): input array
-            skipped (bool): number of samples to skip the beginning
-        """
-        if numpy.isscalar(data):
-            return data
-        if data.size == 1:
-            return data[0]
-        return data[skipped:]
